package com.jjt.inventory.controller;

import java.util.List;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.jjt.common.annotation.Log;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.domain.AjaxResult;
import com.jjt.common.enums.BusinessType;
import com.jjt.inventory.domain.TwinCalcHourBp;
import com.jjt.inventory.service.ITwinCalcHourBpService;
import com.jjt.common.utils.poi.ExcelUtil;
import com.jjt.common.core.page.TableDataInfo;

/**
 * 白坯仓库小时数据Controller
 *
 * @author wukai
 * @date 2025-06-10
 */
@Api(tags="白坯仓库小时数据")
@RestController
@RequestMapping("/inventory/bpHour")
public class TwinCalcHourBpController extends BaseController{
    @Resource
    private ITwinCalcHourBpService twinCalcHourBpService;

    /**
     * 查询白坯仓库小时数据列表
     */
    @ApiOperation("查询白坯仓库小时数据列表")
    //@PreAuthorize("@ss.hasPermi('inventory:bpHour:list')")
    @GetMapping("/list")
    public TableDataInfo list(TwinCalcHourBp twinCalcHourBp)
    {
        startPage();
        List<TwinCalcHourBp> list = twinCalcHourBpService.selectTwinCalcHourBpList(twinCalcHourBp);
        return getDataTable(list);
    }

    /**
     * 导出白坯仓库小时数据列表
     */
    @ApiOperation("导出白坯仓库小时数据列表")
    //@PreAuthorize("@ss.hasPermi('inventory:bpHour:export')")
    @Log(title = "白坯仓库小时数据", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TwinCalcHourBp twinCalcHourBp)
    {
        List<TwinCalcHourBp> list = twinCalcHourBpService.selectTwinCalcHourBpList(twinCalcHourBp);
        ExcelUtil<TwinCalcHourBp> util = new ExcelUtil<TwinCalcHourBp>(TwinCalcHourBp.class);
        util.exportExcel(response, list, "白坯仓库小时数据数据");
    }

    /**
     * 获取白坯仓库小时数据详细信息
     */
    @ApiOperation("获取白坯仓库小时数据详细信息")
    //@PreAuthorize("@ss.hasPermi('inventory:bpHour:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(twinCalcHourBpService.selectTwinCalcHourBpById(id));
    }

    /**
     * 新增白坯仓库小时数据
     */
    @ApiOperation("新增白坯仓库小时数据")
    //@PreAuthorize("@ss.hasPermi('inventory:bpHour:add')")
    @Log(title = "白坯仓库小时数据", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TwinCalcHourBp twinCalcHourBp)
    {
        return toAjax(twinCalcHourBpService.insertTwinCalcHourBp(twinCalcHourBp));
    }

    /**
     * 修改白坯仓库小时数据
     */
    @ApiOperation("修改白坯仓库小时数据")
    //@PreAuthorize("@ss.hasPermi('inventory:bpHour:edit')")
    @Log(title = "白坯仓库小时数据", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TwinCalcHourBp twinCalcHourBp)
    {
        return toAjax(twinCalcHourBpService.updateTwinCalcHourBp(twinCalcHourBp));
    }

    /**
     * 删除白坯仓库小时数据
     */
    @ApiOperation("删除白坯仓库小时数据")
    //@PreAuthorize("@ss.hasPermi('inventory:bpHour:remove')")
    @Log(title = "白坯仓库小时数据", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(twinCalcHourBpService.deleteTwinCalcHourBpByIds(ids));
    }
}
